import Vue from 'vue'
import VueRouter from 'vue-router'
import login from '../views/login.vue'
import home from '../views/home.vue'
import devinfo from '../views/devinfo.vue'
import advancedConfig from '../views/advancedConfig.vue'
import wan from '../views/network/wan.vue'
import lan from '../views/network/lan.vue'
import system from '../views/system/system.vue'
import date from '../views/system/date.vue'
import ping from '../views/system/ping.vue'
import log from '../views/log.vue'
import cacert from '../views/cert/cacert.vue'
import devcert from '../views/cert/cert.vue'
import sslClient from '../views/vpn/ssl-client.vue'
import sslServer from '../views/vpn/ssl-server.vue'
import ipsecClient from '../views/vpn/ipsec-client.vue'
import ipsecServer from '../views/vpn/ipsec-server.vue'
import passwd from '../views/system/passwd.vue'

Vue.use(VueRouter)

const routes = [
  {
    path: '/login',
    name: 'login',
    component: login
  },
  {
    path: '/',
    name: 'home',
    redirect: '/devinfo',
    component: home,
    children: [
      {
        path: '/devinfo',
        name: 'devinfo',
        component: devinfo
      },
      {
        path: '/advancedConfig',
        name: 'advancedConfig',
        redirect: '/advancedConfig/wan',
        component: advancedConfig,
        children: [
          {
            path: 'wan',
            name: 'wan',
            component: wan
          },
          {
            path: 'lan',
            name: 'lan',
            component: lan
          },
          {
            path: 'system',
            name: 'system',
            component: system
          },
          {
            path: 'date',
            name: 'date',
            component: date
          },
          {
            path: 'ping',
            name: 'ping',
            component: ping
          },
          {
            path: 'log/:type',
            name: 'log',
            component: log
          },
          {
            path: 'cacert',
            name: 'cacert',
            component: cacert
          },
          {
            path: 'devcert',
            name: 'devcert',
            component: devcert
          },
          {
            path: 'sslClient',
            name: 'sslClient',
            component: sslClient
          },
          {
            path: 'sslServer',
            name: 'sslServer',
            component: sslServer
          },
          {
            path: 'ipsecClient',
            name: 'ipsecClient',
            component: ipsecClient
          },
          {
            path: 'ipsecServer',
            name: 'ipsecServer',
            component: ipsecServer
          },
          {
            path: 'passwd',
            name: 'passwd',
            component: passwd
          }
        ]
      }
    ]
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})
router.beforeEach((to, from, next) => {
  if (to.path === from.path) return
  // 此处判断登录状态  失效则退回登录页  清空登录状态
  const token = sessionStorage.getItem('token')
  if (!token && !/\/login$/.test(to.path)) {
    next('/login')
  }
  next()
})
export default router
