import Vue from 'vue'
import Vuex from 'vuex'
import axios from '../../plub/axios'
Vue.use(Vuex)
const api = {
  login: '/api/login',
  passwd: '/api/passwd',
  devinfo: '/api/devinfo',
  cpu: '/api/cpu',
  memory: '/api/memory',
  vpnstate: '/api/vpnstate',
  // wna
  wan: '/api/wanupdate',
  wanquery: '/api/wanquery',
  wanup: '/api/wanup',
  wandown: '/api/wanDown',
  // lan
  lan: '/api/lanupdate',
  lanquery: '/api/lanquery',
  lanup: '/api/lanup',
  landown: '/api/lanDown',
  // 设备重启
  reboot: '/api/reboot',
  // 设置时间
  setdate: '/api/setdate',
  // 连接测试
  ping: '/api/ping',
  // 日志查询
  logquery: '/api/logquery',
  // ca证书
  cadelete: '/api/cadelete',
  caquery: '/api/caquery',
  // 设备证书
  sigcertdelete: '/api/sigcertdelete',
  sigcacertquery: '/api/sigcacertquery',
  sigcertreq: '/api/sigcertreq',
  // sslvpn
  sslState: '/api/ssl/state',
  sslClient: '/api/ssl/client',
  sslServer: '/api/ssl/server',
  // ipsecvpn
  ipsecState: '/api/ipsec/state',
  ipsecClient: '/api/ipsec/client',
  ipsecServer: '/api/ipsec/server',
  // 恢复默认配置
  recover: '/api/recover',
  // NTP配置
  ntp: '/api/ntp'
}
export default new Vuex.Store({
  state: {
    username: sessionStorage.getItem('username'),
    devinfo: { profile: sessionStorage.getItem('profile') },
    cpudata: {},
    memorydata: {},
    vpnstate: null,
    wandata: null,
    landata: null,
    logdata: null,
    cadata: [],
    sigdata: [],
    secdata: null,
    ssldata: null
  },
  mutations: {
    login (state, { username, token }) {
      state.username = username
      sessionStorage.setItem('username', username)
      sessionStorage.setItem('token', token)
    },
    devinfo (state, payload) {
      sessionStorage.setItem('profile', payload.data.profile)
      state.devinfo = payload.data
    },
    memory (state, payload) {
      state.memorydata = payload.data
    },
    cpu (state, payload) {
      state.cpudata = payload.data
    },
    vpnstate (state, payload) {
      state.vpnstate = payload.data
    },
    wanquery (state, payload) {
      state.wandata = payload.data
    },
    lanquery (state, payload) {
      state.landata = payload.data
    },
    logquery (state, payload) {
      state.logdata = payload.data
    },
    caquery (state, payload) {
      state.cadata = payload.data
    },
    sigcacertquery (state, payload) {
      state.sigdata = payload.data
    },
    getSSLClient (state, payload) {
      state.ssldata = payload.data
    },
    getSSLServer (state, payload) {
      state.ssldata = payload.data
    },
    getIPSecServer (state, payload) {
      state.secdata = payload.data
    },
    getIPSecClient (state, payload) {
      state.secdata = payload.data
    }
  },
  actions: {
    // 登录
    async login ({ commit }, { userName, password }) {
      const res = await axios.post(api.login, { userName, password })
      if (res.data && res.data.errcode === 0) {
        commit('login', { username: userName, token: res.data.token })
      }
      return res.data
    },
    // 登录
    async changepass ({ commit }, { userName, oldpass, newpass }) {
      const res = await axios.post(api.passwd, { userName, newpass, oldpass })
      return res.data
    },
    // 获取设备信息
    async getdevinfo ({ commit }) {
      const res = await axios.get(api.devinfo)
      commit('devinfo', res.data)
      return res.data
    },
    // 获取cpu使用状态
    async getcpu ({ commit }) {
      const res = await axios.get(api.cpu)
      if (res) {
        commit('cpu', res.data)
        return res.data
      }
    },
    // 获取内存使用状态
    async getmemory ({ commit }) {
      const res = await axios.get(api.memory)
      if (res) {
        commit('memory', res.data)
        return res.data
      }
    },
    // 获取vpn连接状态
    async getvpnstate ({ commit }) {
      const res = await axios.get(api.vpnstate)
      if (res) {
        commit('vpnstate', res.data)
        return res.data
      }
    },
    // 修改wan
    async setwan ({ commit }, payload) {
      const res = await axios.post(api.wan, payload)
      return res.data
    },
    // 查询wan
    async wanquery ({ commit }) {
      const res = await axios.get(api.wanquery)
      commit('wanquery', res.data)
      return res.data
    },
    // 停止wan网卡
    async wandown ({ commit }) {
      const res = await axios.get(api.wandown)
      return res.data
    },
    // 启动wan网卡
    async wanup ({ commit }) {
      const res = await axios.get(api.wanup)
      return res.data
    },
    // 修改lan
    async setlan ({ commit }, payload) {
      const res = await axios.post(api.lan, payload)
      return res.data
    },
    // 查询lan
    async lanquery ({ commit }) {
      const res = await axios.get(api.lanquery)
      commit('wanquery', res.data)
      return res.data
    },
    // 停止lan网卡
    async landown ({ commit }) {
      const res = await axios.get(api.landown)
      return res.data
    },
    // 启动lan网卡
    async lanup ({ commit }) {
      const res = await axios.get(api.lanup)
      return res.data
    },
    // 设备重启
    async reboot ({ commit }) {
      await axios.get(api.reboot)
    },
    // 设置时间
    async setdate ({ commit }, payload) {
      const res = await axios.post(api.setdate, payload)
      return res.data
    },
    // 连接测试
    async ping ({ commit }, payload) {
      const res = await axios.post(api.ping, payload)
      return res.data
    },
    // 日志查询
    async logquery ({ commit }, { type } = {}) {
      const res = await axios.get(`${api.logquery}?type=${type}`)
      commit('logquery', res.data)
      return res.data
    },
    // 删除ca证书
    async cadelete ({ commit }, payload) {
      const res = await axios.get(`${api.cadelete}?uuid=${payload.uuid}`)
      return res.data
    },
    // ca证书查询
    async caquery ({ commit }) {
      const res = await axios.get(`${api.caquery}`)
      commit('caquery', res.data)
      return res.data
    },
    // 删除设备证书
    async sigcertdelete ({ commit }, payload) {
      const res = await axios.get(`${api.sigcertdelete}?uuid=${payload.uuid}`)
      return res.data
    },
    // 设备证书查询
    async sigcacertquery ({ commit }) {
      const res = await axios.get(`${api.sigcacertquery}`)
      commit('sigcacertquery', res.data)
      return res.data
    },
    // 申请书
    async sigcertreq ({ commit }, payload) {
      const res = await axios.post(`${api.sigcertreq}`, payload)
      return res.data
    },
    // 启动停止重启sslState
    async sslState ({ commit }, { type } = {}) {
      const res = await axios.get(`${api.sslState}?type=${type}`)
      return res.data
    },
    // 查询sslvpn客户端
    async getSSLClient ({ commit }) {
      const res = await axios.get(`${api.sslClient}`)
      commit('getSSLClient', res)
      return res.data
    },
    // 查询sslvpn服务端
    async getSSLServer ({ commit }) {
      const res = await axios.get(`${api.sslServer}`)
      commit('getSSLServer', res)
      return res.data
    },
    // sslvpn客户端添加
    async setSSLClient ({ commit }, payload) {
      const res = await axios.post(`${api.sslClient}`, payload)
      return res.data
    },
    // sslvpn服务端添加
    async setSSLServer ({ commit }, payload) {
      const res = await axios.post(`${api.sslServer}`, payload)
      return res.data
    },
    // 启动停止重启ipsecvpnstate
    async ipsecState ({ commit }, { type } = {}) {
      const res = await axios.get(`${api.ipsecState}?type=${type}`)
      return res.data
    },
    // 查询ipsecvpn客户端
    async getIPSecClient ({ commit }) {
      const res = await axios.get(`${api.ipsecClient}`)
      commit('getIPSecClient', res)
      return res.data
    },
    // 查询ipsecvpn服务端
    async getIPSecServer ({ commit }) {
      const res = await axios.get(`${api.ipsecServer}`)
      commit('getIPSecServer', res)
      return res.data
    },
    // ipsecvpn客户端添加
    async setIPSecClient ({ commit }, payload) {
      const res = await axios.post(`${api.ipsecClient}`, payload)
      return res.data
    },
    // ipsecvpn服务端添加
    async setIPSecServer ({ commit }, payload) {
      const res = await axios.post(`${api.ipsecServer}`, payload)
      return res.data
    },
    // 恢复默认配置
    async recover ({ commit }) {
      const res = await axios.get(api.recover)
      return res.data || res
    },
    // 设置NTP
    async setntp ({ commit }, payload) {
      const res = await axios.post(api.ntp, payload)
      return res.data
    },
    // 获取NTP状态
    async getntp ({ commit }, payload) {
      const res = await axios.get(api.ntp)
      return res.data
    }
  },
  modules: {
  }
})
